# GReNaDIne: Gene Regulatory Network Data-driven Inference

This Python 3.7 package allows to infer Gene Regulatory Networks through several
Data-driven methods. Pre-processing and evaluation methods are also included.

### Installation:

`pip install GReNaDIne`

### Tutorials:

Check the jupyter notebook tutorials located in the __tutorial__ folder
+ `Infer_dream5_E_coli_GRN_using_GENIE3.ipynb` to infer GRNs using the GENIE3 method (random forest regression)
+ `Infer_dream5_E_coli_GRN_using_SVMs.ipynb` to infer GRNs using the SVM method (SVM classification)

### Authors:

For bug reports and feedback do not hesitate to contact the authors

+ [Sergio Peignier](sergio.peignier@insa-lyon.fr)
+ [Pauline Schmitt](pauline.schmitt@insa-lyon.fr)

### Maintainer:

+ [Sergio Peignier](sergio.peignier@insa-lyon.fr)
